@@ -42,6 +42,11 @@ subs(as.mvp("a+b+c"), x="1+a",a="x^6")
 ## -----------------------------------------------------------------------------
 as.mvp("a+b") %>% subs(a="a^2+b^2") %>% subs(b="x^6")
 
+## ----subvec_example-----------------------------------------------------------
+p <- rmvp(6,2,2,letters[1:3])
+p
+subvec(p,a=1,b=2,c=1:5)   # supply a named list of vectors
+
 ## -----------------------------------------------------------------------------
 (S <- as.mvp("a + 5 a^5*b^2*c^8 -3 x^2 a^3 b c^3"))
 deriv(S, letters[1:3])
@@ -100,21 +105,49 @@ invert(p)
 ## -----------------------------------------------------------------------------
 p + as.mvp("z^6")
 
+## ----introtodisord------------------------------------------------------------
+a <- as.mvp("5 + 8*x^2*y - 13*y*x^2 + 11*z - 3*x*yz")
+a
+coeffs(a)
+
+## ----disordpluscoeffs,error=TRUE----------------------------------------------
+b <- a*2
+b
+coeffs(a) + coeffs(b)
+
+## ----disordRsingleobjectstuff-------------------------------------------------
+coeffs(a) > 0
+coeffs(a) + coeffs(a)^4
+
+## ----disordextract------------------------------------------------------------
+coeffs(a)[coeffs(a) > 0]
+
+## ----disordnotallowed,error=TRUE----------------------------------------------
+coeffs(a)[coeffs(b) > 0]
+
+## ----disordreplace------------------------------------------------------------
+coeffs(a)[coeffs(a)<0] <- coeffs(a)[coeffs(a)<0] + 1000 # add 1000 to every negative coefficient
+a
+
+## ----usemagirttr--------------------------------------------------------------
+library("magrittr")
+b
+coeffs(b)[coeffs(b)%%3==1] %<>% `+`(100)  # add 100 to every element equal to 1 modulo 3
+b
+
+## -----------------------------------------------------------------------------
+x <- as.mvp("1 - 0.11*x + 0.005*x*y")^2
+x
+
+## ----zapmvp-------------------------------------------------------------------
+cx <- coeffs(x)
+cx[abs(cx) < 0.01] <- 0
+coeffs(x) <- cx
+x
+
 ## -----------------------------------------------------------------------------
 knight(2)
 
 ## -----------------------------------------------------------------------------
 constant(knight(4)^4)
 
-## -----------------------------------------------------------------------------
-library("spray")
-library("mpoly")
-n <- 100
-k <- kahle(n, r = 3, p = 1:3, symbols = paste0("x", sprintf("%03d", 1:n)))
-
-## -----------------------------------------------------------------------------
-library("microbenchmark")
-
-spray_k <- mvp_to_spray(k)
-microbenchmark( k^2, spray_k^2 )
-
